pub enum MatchHint {
Unsupported,
NoMatches,
MaybeMatch(usize),
}Expand description
Hinting where the pattern might be matching the target
Variants
Unsupported
A match hint could not be generated
NoMatches
The pattern will not match the target
MaybeMatch(usize)
The pattern may match the target at the given offset