pub struct BinaryMatcher<'a, S: Stack<u32>, C: Stack<usize>> { /* private fields */ }Expand description
The BinaryMatcher is responsible for searching a BinaryPattern within a MatchTarget.
Use BinaryMatcher::next_match to iterate through matches of the specified pattern.
Implementations
Sourceimpl<'a, S: Stack<u32>, C: Stack<usize>> BinaryMatcher<'a, S, C>
impl<'a, S: Stack<u32>, C: Stack<usize>> BinaryMatcher<'a, S, C>
Sourcepub fn next_match(&mut self) -> Option<&[u32]>
pub fn next_match(&mut self) -> Option<&[u32]>
Finds the next match for the associated BinaryPattern within the MatchTarget.
Returns
Some(&[u32])containing the saved stack. The first element of the saved stack represents the start of the matched location.
Subsequent elements can be pushed using theAtom::SaveCursoratom or the'command within the binary pattern.Noneif no further matches are available.