bmatcher_core Enum Atom Copy item path Source pub enum Atom {
ByteSequence {
seq_start: usize ,
seq_end: usize ,
},
WildcardFixed(usize ),
WildcardRange {
min: usize ,
max: usize ,
},
Jump(JumpType ),
Read(ReadWidth ),
Branch {
left_len: usize ,
right_len: usize ,
},
CursorPush,
CursorPop {
advance: usize ,
},
SaveCursor,
SaveConstant(u32 ),
}Expand description An atom represents a single operation that the matcher should perform.
Match a sequence of bytes from the sequence array.
Skip a fixed number of bytes.
Skip a variable number of bytes.
Jump to the relative / absolute based on the binary data the current cursor location.
Read the data value of a specified size at the current cursors location and save it to the save stack.
This also advances the data cursor by the specified size.
Match any one of the two subexpressions
and then continue where we left of.
Fields Length of the left subpattern
Length of the right subpattern
Push the cursor location to the cursor stack
Pop the cursor location from the cursor stack and advance by X bytes
Save the current cursor position to the save stack
Save the constant to the save stack.
This can be usefull to save which branch has been taken.
Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more Compares and returns the maximum of two values.
Read more Compares and returns the minimum of two values.
Read more Restrict a value to a certain interval.
Read more Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
This method returns an ordering between
self and
other values if one exists.
Read more Tests less than (for
self and
other) and is used by the
< operator.
Read more Tests less than or equal to (for
self and
other) and is used by the
<= operator.
Read more Tests greater than (for
self and
other) and is used by the
>
operator.
Read more Tests greater than or equal to (for
self and
other) and is used by
the
>= operator.
Read more Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dst.
Read more Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.