pub fn execute_with_stack<'a, S: Stack<u32>, C: Stack<usize>>(
target: &'a dyn MatchTarget,
pattern: &'a dyn BinaryPattern,
save_stack: S,
cursor_stack: C,
) -> BinaryMatcher<'a, S, C>Expand description
Match a target against a binary pattern and supply the save and cursor stacks on your own